==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/transfer/kotlin/inputs/AccessPosixProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.transfer.kotlin.inputs

import com.pulumi.aws.transfer.inputs.AccessPosixProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property gid The POSIX group ID used for all EFS operations by this user.
 * @property secondaryGids The secondary POSIX group IDs used for all EFS operations by this user.
 * @property uid The POSIX user ID used for all EFS operations by this user.
 */
public data class AccessPosixProfileArgs(
    public val gid: Output<Int>,
    public val secondaryGids: Output<List<Int>>? = null,
    public val uid: Output<Int>,
) : ConvertibleToJava<com.pulumi.aws.transfer.inputs.AccessPosixProfileArgs> {
    override fun toJava(): com.pulumi.aws.transfer.inputs.AccessPosixProfileArgs =
        com.pulumi.aws.transfer.inputs.AccessPosixProfileArgs.builder()
            .gid(gid.applyValue({ args0 -> args0 }))
            .secondaryGids(secondaryGids?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .uid(uid.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AccessPosixProfileArgs].
 */
@PulumiTagMarker
public class AccessPosixProfileArgsBuilder internal constructor() {
    private var gid: Output<Int>? = null

    private var secondaryGids: Output<List<Int>>? = null

    private var uid: Output<Int>? = null

    /**
     * @param value The POSIX group ID used for all EFS operations by this user.
     */
    @JvmName("udlsmwbdwdmucwbx")
    public suspend fun gid(`value`: Output<Int>) {
        this.gid = value
    }

    /**
     * @param value The secondary POSIX group IDs used for all EFS operations by this user.
     */
    @JvmName("tybtflgxacrgugti")
    public suspend fun secondaryGids(`value`: Output<List<Int>>) {
        this.secondaryGids = value
    }

    @JvmName("vveymjoxuykkyipn")
    public suspend fun secondaryGids(vararg values: Output<Int>) {
        this.secondaryGids = Output.all(values.asList())
    }

    /**
     * @param values The secondary POSIX group IDs used for all EFS operations by this user.
     */
    @JvmName("guphddjqpcagpmww")
    public suspend fun secondaryGids(values: List<Output<Int>>) {
        this.secondaryGids = Output.all(values)
    }

    /**
     * @param value The POSIX user ID used for all EFS operations by this user.
     */
    @JvmName("aumlfgbgbadlmrgg")
    public suspend fun uid(`value`: Output<Int>) {
        this.uid = value
    }

    /**
     * @param value The POSIX group ID used for all EFS operations by this user.
     */
    @JvmName("bygksmomoactmpvc")
    public suspend fun gid(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.gid = mapped
    }

    /**
     * @param value The secondary POSIX group IDs used for all EFS operations by this user.
     */
    @JvmName("ksxhpufrdibqkjcp")
    public suspend fun secondaryGids(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secondaryGids = mapped
    }

    /**
     * @param values The secondary POSIX group IDs used for all EFS operations by this user.
     */
    @JvmName("rdqprlqjyfmcrswo")
    public suspend fun secondaryGids(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.secondaryGids = mapped
    }

    /**
     * @param value The POSIX user ID used for all EFS operations by this user.
     */
    @JvmName("nfettiyscgtukydo")
    public suspend fun uid(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.uid = mapped
    }

    internal fun build(): AccessPosixProfileArgs = AccessPosixProfileArgs(
        gid = gid ?: throw PulumiNullFieldException("gid"),
        secondaryGids = secondaryGids,
        uid = uid ?: throw PulumiNullFieldException("uid"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/transfer/kotlin/inputs/AccessPosixProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.transfer.kotlin.inputs

import com.pulumi.aws.transfer.inputs.AccessPosixProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property gid The POSIX group ID used for all EFS operations by this user.
 * @property secondaryGids The secondary POSIX group IDs used for all EFS operations by this user.
 * @property uid The POSIX user ID used for all EFS operations by this user.
 */
public data class AccessPosixProfileArgs(
    public val gid: Output<Int>,
    public val secondaryGids: Output<List<Int>>? = null,
    public val uid: Output<Int>,
) : ConvertibleToJava<com.pulumi.aws.transfer.inputs.AccessPosixProfileArgs> {
    override fun toJava(): com.pulumi.aws.transfer.inputs.AccessPosixProfileArgs =
        com.pulumi.aws.transfer.inputs.AccessPosixProfileArgs.builder()
            .gid(gid.applyValue({ args0 -> args0 }))
            .secondaryGids(secondaryGids?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .uid(uid.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AccessPosixProfileArgs].
 */
@PulumiTagMarker
public class AccessPosixProfileArgsBuilder internal constructor() {
    private var gid: Output<Int>? = null

    private var secondaryGids: Output<List<Int>>? = null

    private var uid: Output<Int>? = null

    /**
     * @param value The POSIX group ID used for all EFS operations by this user.
     */
    @JvmName("hnxxaexfuygxuxfm")
    public suspend fun gid(`value`: Output<Int>) {
        this.gid = value
    }

    /**
     * @param value The secondary POSIX group IDs used for all EFS operations by this user.
     */
    @JvmName("efsvcmwncfkmcnhi")
    public suspend fun secondaryGids(`value`: Output<List<Int>>) {
        this.secondaryGids = value
    }

    @JvmName("unxmrvasguteyidp")
    public suspend fun secondaryGids(vararg values: Output<Int>) {
        this.secondaryGids = Output.all(values.asList())
    }

    /**
     * @param values The secondary POSIX group IDs used for all EFS operations by this user.
     */
    @JvmName("gupnxuagyviosaat")
    public suspend fun secondaryGids(values: List<Output<Int>>) {
        this.secondaryGids = Output.all(values)
    }

    /**
     * @param value The POSIX user ID used for all EFS operations by this user.
     */
    @JvmName("vttlvmkkcndhivdf")
    public suspend fun uid(`value`: Output<Int>) {
        this.uid = value
    }

    /**
     * @param value The POSIX group ID used for all EFS operations by this user.
     */
    @JvmName("ixbhisfciadwqdly")
    public suspend fun gid(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.gid = mapped
    }

    /**
     * @param value The secondary POSIX group IDs used for all EFS operations by this user.
     */
    @JvmName("sawvqthiuybdgqmq")
    public suspend fun secondaryGids(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secondaryGids = mapped
    }

    /**
     * @param values The secondary POSIX group IDs used for all EFS operations by this user.
     */
    @JvmName("fdajwdcikkoiqxkv")
    public suspend fun secondaryGids(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.secondaryGids = mapped
    }

    /**
     * @param value The POSIX user ID used for all EFS operations by this user.
     */
    @JvmName("xvbcfpbvontxfeof")
    public suspend fun uid(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.uid = mapped
    }

    internal fun build(): AccessPosixProfileArgs = AccessPosixProfileArgs(
        gid = gid ?: throw PulumiNullFieldException("gid"),
        secondaryGids = secondaryGids,
        uid = uid ?: throw PulumiNullFieldException("uid"),
    )
}
